Changelog
=========

<!--next-version-placeholder-->

## v0.3.3 (2022-09-12)
### :robot:
* [FIX:robot:] Add the Missing Error Schema Fields ([`a4366e9`](https://github.com/cowofevil/flask-ligand/commit/a4366e9df0badebd1cf050390a1eb69ea3798fcb))

## v0.3.2 (2022-09-10)
### :robot:
* [FIX:robot:] Change Type Definition for BEARER_AUTH ([`1c10a1b`](https://github.com/cowofevil/flask-ligand/commit/1c10a1b7349cce80b72252fbed67f864c426c38b))

### Other
* :arrow_up: Update black requirement from ~=22.6 to ~=22.8 ([`38c5e43`](https://github.com/cowofevil/flask-ligand/commit/38c5e4355d42c12909314e7f4145e6d0bb40107b))
* :arrow_up: Update types-setuptools requirement from ~=65.1 to ~=65.3 ([`e34790b`](https://github.com/cowofevil/flask-ligand/commit/e34790ba04c1f77e40c239b1c40cd84d0603cf0d))
* :arrow_up: Update python-dotenv requirement from ~=0.20 to ~=0.21 ([`1de2b4d`](https://github.com/cowofevil/flask-ligand/commit/1de2b4d7ca85dfba0231c0692c4b3537f2011e47))

## v0.3.1 (2022-09-08)
### :robot:
* [FIX:robot:] Add Note about Building RTD Correctly ([`e27d050`](https://github.com/cowofevil/flask-ligand/commit/e27d050e9888353e8aa7635eff59c58237c4f176))

### Other
* [501] Add readthedocs Documentation ([`a907fdc`](https://github.com/cowofevil/flask-ligand/commit/a907fdcbc28e1bcf60b71500679f3c6c8044af5c))
* [FIX] Add Migrations Directory for Integration Tests ([`3310971`](https://github.com/cowofevil/flask-ligand/commit/3310971baa7574a28f35fd9af60d17d8bb8369ad))
* [CHORE] Increase Code Coverage Accuracy ([`3597db7`](https://github.com/cowofevil/flask-ligand/commit/3597db7f932ef2c93f3d263e1df557d52d9097aa))

## v0.3.0 (2022-08-30)
### :sparkles:
* [516:sparkles:] Support Database Migrations ([`b8c062b`](https://github.com/cowofevil/flask-ligand/commit/b8c062b925ea6f83c083a90398e5ee41ca03344e))

## v0.2.0 (2022-08-27)
### :sparkles:
* [510:sparkles:] Configurable Roles for RBAC Verification ([`d8e80a4`](https://github.com/cowofevil/flask-ligand/commit/d8e80a428875958a9af7e6774c8cfa2a370dab94))

### Other
* :arrow_up: Update types-setuptools requirement from ~=63.4 to ~=65.1 ([`7c8ef3a`](https://github.com/cowofevil/flask-ligand/commit/7c8ef3a6f19bf1f752d25f92ced9f22c67a24986))

## v0.1.3 (2022-08-25)
### :robot:
* [507:robot:] Configure Database Provider and URI ([`7e3d0c7`](https://github.com/cowofevil/flask-ligand/commit/7e3d0c7e1ce231893be80b6fd78802f0f589c347))

### Other
* [FIX] Enable SQLite Memory Database URI for Local Environment ([`fd5de8a`](https://github.com/cowofevil/flask-ligand/commit/fd5de8a4e7ad60368caa4e5c4604a944ab54c3dd))

## v0.1.2 (2022-08-18)
### :robot:
* [504:robot:] Fix Configuration Setting Issue and Update Docs ([`c3aea6c`](https://github.com/cowofevil/flask-ligand/commit/c3aea6c9f40b9f1bd2dd3da96f551733985c0332))

### Other
* [CHORE] Merge Coverage and Mypy Configuration into Pyproject ([`c187bf4`](https://github.com/cowofevil/flask-ligand/commit/c187bf42dea9b6316dee5a49eed2e9473e2f39c3))

## v0.1.1 (2022-08-18)
### :robot:
* [FIX:robot:] Update Flask and Fix Type Checking ([`7dbc587`](https://github.com/cowofevil/flask-ligand/commit/7dbc587d71bee3b111dc03ff539222959cbce426))

### Other
* :arrow_up: Update flask-smorest requirement from ~=0.38 to ~=0.39 ([`77d3679`](https://github.com/cowofevil/flask-ligand/commit/77d3679b1671a8ad3d405ded3a9c86e8c6713b32))
* :arrow_up: Update pygments requirement from ~=2.12 to ~=2.13 ([`1d75cd5`](https://github.com/cowofevil/flask-ligand/commit/1d75cd5e8b752a1f0c3dbffc67c07baa7f3c693b))
* :arrow_up: Update sqlalchemy-utils requirement from ~=0.32 to ~=0.38 ([`475ac06`](https://github.com/cowofevil/flask-ligand/commit/475ac0671becde3392d063c9045779bfed3c3fb8))

## v0.1.0 (2022-08-17)
### :sparkles:
* [473:sparkles:] Sanitize Codebase and Rename Everything to 'flask-ligand' ([`730dc0c`](https://github.com/cowofevil/flask-ligand/commit/730dc0c2825a8f0c40fee141e2001c46ec924700))

### Other
* Initial commit ([`7893f0d`](https://github.com/cowofevil/flask-ligand/commit/7893f0de70b26a853ad86a243d16b2d5589ba968))
